Community Resources
===================

Below are a few community resources about Rally. If you find an interesting article, talk, or custom tracks, `raise an issue <https://github.com/elastic/rally/issues>`_  or `open a pull request <https://github.com/elastic/rally/pulls>`_.

Videos
------

.. raw:: html

   <iframe width="560" height="315" src="https://www.youtube.com/embed/HriBY2zoChw" frameborder="0" allowfullscreen></iframe>

.. raw:: html

   <iframe width="560" height="315" src="https://www.youtube.com/embed/-jgmnpG_P-Y" frameborder="0" allowfullscreen></iframe>

.. raw:: html

   <iframe width="560" height="315" src="https://www.youtube.com/embed/T0tRDNDjHcI" frameborder="0" allowfullscreen></iframe>

Articles
--------

`Using Rally to benchmark Elasticsearch queries <http://blog.scottlogic.com/2016/11/22/using-rally-to-benchmark-elasticsearch.html>`_ by Darren Smith